# RecordV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**orcid_identifier** | [**OrcidIdentifierV30**](OrcidIdentifierV30.md) |  | [optional] 
**preferences** | [**PreferencesV30**](PreferencesV30.md) |  | [optional] 
**history** | [**HistoryV30**](HistoryV30.md) |  | [optional] 
**person** | [**PersonV30**](PersonV30.md) |  | [optional] 
**activities_summary** | [**ActivitiesSummaryV30**](ActivitiesSummaryV30.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

